# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic 
Versioning](https://semver.org/spec/v2.0.0.html).


## [X.X.X]

### Added

### Changed

### Deprecated

### Removed

### Fixed

## [0.1.0] = 2025-09-07

First public repo